==> dafne-1.8a4.tar.gz: dafne-1.8a4/test/testDL.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

#  Copyright (c) 2021 Dafne-Imaging Team
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.

from src.dafne_dl import DynamicDLModel
from src.dafne.utils.dicomUtils import loadDicomFile
#import numpy as np
from test.plotSegmentations import plotSegmentations
import matplotlib.pyplot as plt

def testSegmentation(modelPath, dicomPath):
    thighModel = DynamicDLModel.Load(open(modelPath, 'rb'))
    
    ima, info = loadDicomFile(dicomPath)
    
    resolution = info.PixelSpacing
    out = thighModel({'image': ima, 'resolution': resolution})
    
    plotSegmentations(ima, out)
    
    plt.show()
    
def testClassification(modelPath, dicomPath):
    classModel = DynamicDLModel.Load(open(modelPath, 'rb'))
    
    ima, info = loadDicomFile(dicomPath)
    
    resolution = info.PixelSpacing
    out = classModel({'image': ima, 'resolution': resolution})
    print(out)

==> dafne-1.9a2.tar.gz: dafne-1.9a2/test/testDL.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

#  Copyright (c) 2021 Dafne-Imaging Team
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.

from src.dafne_dl import DynamicDLModel
from dicomUtils import loadDicomFile
#import numpy as np
from test.plotSegmentations import plotSegmentations
import matplotlib.pyplot as plt

def testSegmentation(modelPath, dicomPath):
    thighModel = DynamicDLModel.Load(open(modelPath, 'rb'))
    
    ima, info = loadDicomFile(dicomPath)
    
    resolution = info.PixelSpacing
    out = thighModel({'image': ima, 'resolution': resolution})
    
    plotSegmentations(ima, out)
    
    plt.show()
    
def testClassification(modelPath, dicomPath):
    classModel = DynamicDLModel.Load(open(modelPath, 'rb'))
    
    ima, info = loadDicomFile(dicomPath)
    
    resolution = info.PixelSpacing
    out = classModel({'image': ima, 'resolution': resolution})
    print(out)
